@@ -114,15 +114,19 @@ class StockFactorType(enum.IntEnum):
     ALPHA101 = 12  # WorldQuant alpha101
     SPEC = 13  # 一些特殊因子
 
+
 # 基金因子类型
 class FundFactorType(enum.IntEnum):
     BASIC = 1  # 基础
     DERIVED = 2 # 高级
     SCORE = 3 # 分数
 
+
 # 行业分类类型
 class IndClassType(enum.IntEnum):
-    SWI = 1  # 申万行业指数
+    SWI1 = 1  # 申万一级行业指数
+    SWI2 = 2  # 申万二级行业指数
+    SWI3 = 3  # 申万三级行业指数
 
 
 class ExchangeID(ReadableEnum):
