@@ -250,8 +250,9 @@ class BasicDataPart1:
         df['is_stock_factor_universe'] = False
         df['tag_method'] = 'PE百分位'
         # index_id是人工起的，所以只能作为参数传进来
+        df = df.set_index('em_id').reindex(index_list)
         df['index_id'] = index_ids
-        df = df.set_index('index_id')
+        df = df.reset_index().set_index('index_id')
         if 'csi_new_ev' in df.index:
             df.loc['csi_new_ev','desc_name'] = '中证新能源汽车'
         if 'csi_biomedi' in df.index:
@@ -1055,6 +1056,133 @@ class BasicDataPart1:
         bond_fund = bond_fund[bond_fund.stock_id.str.contains('.SH') | bond_fund.stock_id.str.contains('.SZ') | bond_fund.stock_id.str.contains('.IB')]
         self._data_helper._upload_basic(bond_fund, BondInFund.__table__.name)
 
+    def stock_tag(self):
+        def get_concept_id(tag_name, raw_concept_id):
+            return f'{tag_name}@{str(raw_concept_id)}'
+        
+        ''' em cpt
+        df = self._raw_data_api.get_em_stock_concept_info()
+        tag_group_id = 'em_cpt_201223'
+        concept_id_dic = {}
+        concept_stock_dic = {}
+        raw_concept_id = 1
+        for r in df.itertuples():
+            if r.concepts is None:
+                continue
+            concept_list = r.concepts.split(',')
+            for concept_i in concept_list:
+                if concept_i not in concept_id_dic:
+                    concept_id_dic[concept_i] = get_concept_id(tag_group_id, raw_concept_id)
+                    raw_concept_id += 1
+                else:
+                    pass
+                
+                if concept_i not in concept_stock_dic:
+                    concept_stock_dic[concept_i] = []
+                else:
+                    concept_stock_dic[concept_i].append(r.codes)
+        concept_df = pd.DataFrame([concept_id_dic]).T
+        concept_df.columns=['tag_id']
+
+        concept_stock_df = pd.DataFrame([concept_stock_dic]).T
+        concept_stock_df.columns=['stock_id']
+        df = concept_df.join(concept_stock_df).explode('stock_id').reset_index()
+        df = df.rename(columns={'index':'tag_name'})
+        df.loc[:,'tag_group_id'] = tag_group_id
+        '''
+        '''
+        tag_group_id = 'dm_cpt_201223'
+        stock_used_cpt = self._basic_data_api.get_fund_stock_concept(tag_group_id)
+        cpt_rules_raw = {'白酒':['白酒'],
+        '5G':['5G概念'],
+        '半导体':['半导体','第三代半导体'],
+        '芯片':['国产芯片'],
+        '光伏':['太阳能'],
+        '农业':['农业种植','生态农业'],
+        '新能源':['新能源车','新能源'],
+        '医疗':['医疗器械','互联医疗','精准医疗'],
+        '医美':['医疗美容'],
+        '银行':['参股银行'],
+        '券商':['参股券商','券商概念'],
+        '黄金':['黄金概念'],
+        '军工':['军工'],
+        '养老':['养老概念']}
+
+        cpt_rules = {}
+        for k, vs in cpt_rules_raw.items():
+            for v in vs:
+                cpt_rules[v] = k
+        concept_id_dic = {}
+        concept_stock_dic = {}
+        raw_concept_id = 1
+        select_cpts = list(cpt_rules.keys())
+        stock_cpt_selected = stock_used_cpt[stock_used_cpt.tag_name.isin(select_cpts)]
+        for r in stock_cpt_selected.itertuples():
+            new_tag_name = cpt_rules[r.tag_name]
+            if new_tag_name not in concept_id_dic:
+                concept_id_dic[new_tag_name] = get_concept_id(tag_group_id, raw_concept_id)
+                raw_concept_id += 1
+            else:
+                pass
+            
+            if new_tag_name not in concept_stock_dic:
+                concept_stock_dic[new_tag_name] = []
+            else:
+                concept_stock_dic[new_tag_name].append(r.stock_id)
+        concept_df = pd.DataFrame([concept_id_dic]).T
+        concept_df.columns=['tag_id']
+
+        concept_stock_df = pd.DataFrame([concept_stock_dic]).T
+        concept_stock_df.columns=['stock_id']
+        df = concept_df.join(concept_stock_df).explode('stock_id').reset_index()
+        df = df.rename(columns={'index':'tag_name'})
+        df.loc[:,'tag_group_id'] = tag_group_id
+        df = df.drop_duplicates(subset=['tag_id','stock_id','tag_group_id'])
+        '''
+        tag_group_id = 'dm_ind_201224'
+        industry_info = self._raw_data_api.get_em_industry_info()
+        stock_info = self._raw_data_api.get_em_stock_info()
+        stock_info.loc[:,'sw_indus_1'] = stock_info.bl_sws_ind_code.map(lambda x: x.split('-')[0] if x is not None else None)
+        ind_rules_raw = {'食品饮料':['食品饮料'],
+                        '消费':['休闲服务','家用电器','纺织服装','食品饮料'],
+                        '可选消费':['休闲服务','家用电器','纺织服装'],
+                        '主要消费':['食品饮料'],
+                        '科技':['电子','计算机','通信'],
+                        '农业':['农林牧渔'],
+                        '医药':['医药生物'],
+                        '券商':['非银金融'],
+                        '金融地产':['房地产','非银金融','银行'],
+                        '金融':['非银金融','银行'],
+                        '地产':['房地产'],
+                        '有色':['有色金属'],
+                        '军工':['国防军工']}
+        # combine rule
+        ind_rules = {}
+        for k, vs in ind_rules_raw.items():
+            for v in vs:
+                if v not in ind_rules:
+                    ind_rules[v] = []
+                ind_rules[v].append(k)
+                
+        # make id 
+        num = 1
+        id_dic = {}
+        for ind in ind_rules_raw:
+            id_dic[ind] = get_concept_id(tag_group_id, num)
+            num += 1
+            
+        _df1 = stock_info[['stock_id','sw_indus_1']]
+        _df2 = industry_info[['em_id','ind_name']].rename(columns={'em_id':'sw_indus_1'})
+        df = pd.merge(_df1, _df2, on='sw_indus_1' )[['stock_id','ind_name']].rename(columns={'ind_name':'tag_name'})
+        df['tag_name_new'] = df.tag_name.map(lambda x: ind_rules.get(x))
+        df = df.dropna().explode('tag_name_new')
+        df.loc[:,'tag_id'] = df.tag_name_new.map(lambda x : id_dic[x])
+        df = df.drop(columns=['tag_name']).rename(columns={'tag_name_new':'tag_name'})
+        df.loc[:,'tag_group_id'] = tag_group_id
+
+
+        self._data_helper._upload_basic(df, StockTag.__table__.name)
+
     def etf_info(self):
         def main_index(x):
             if x == '':
@@ -1081,6 +1209,10 @@ class BasicDataPart1:
         out_market['etf_type'] = '场外'
         result = pd.concat([in_market,out_market], axis=0)
         result = pd.merge(result, index_info[['index_id','desc_name']].rename(columns={'desc_name':"index_name"}), on='index_id')
+        change_fund_list = result[(result.etf_type == '场内') & (result.desc_name.str.contains('ETF联接'))].fund_id.tolist()
+        result = result.set_index('fund_id')
+        result.loc[change_fund_list,'etf_type'] = '场外'
+        result = result.reset_index()
         self._data_helper._upload_basic(result, ETFInfo.__table__.name)
 
     def process_all(self, start_date, end_date):
