@@ -54,8 +54,17 @@ class ManagerDailyCollectionProcessor:
             result.append(mng_info_i)
         result_df = pd.concat(result).drop(columns=['_update_time'])
         _df1 = manager_indicator.set_index(['mng_id','fund_type'])
-        _df2 = result_df.set_index(['mng_id','fund_type'])[['best_fund','profit']]
+        _df2 = result_df.set_index(['mng_id','fund_type'])[['best_fund']]
         df = _df1.join(_df2).reset_index()
+
+        _df_all = df[df.best_fund.isnull()].copy()
+        _df_existed = df[~df.best_fund.isnull()].copy()
+        for r in _df_all.itertuples():
+            _df = fund_manager_info[(fund_manager_info.mng_id == r.mng_id)]
+            best_fund = _df.sort_values(['end_date','start_date'], ascending=[False, True]).fund_id.values[0]
+            _df_all.loc[r.Index,'best_fund'] = best_fund
+        df = pd.concat([_df_all,_df_existed])
+
         replace_dic = {
             'mdd~history_daily':'mdd_history_daily',
             'annual_ret~history_m':'annual_ret_history_m',
@@ -70,7 +79,6 @@ class ManagerDailyCollectionProcessor:
             'mng_id':'基金经理id',
             'name':'姓名',
             'fund_type':'基金类型',
-            'profit':'任期收益',
             'mdd_history_daily':'历史最大回撤',
             'annual_ret_history_m':'历史年化收益',
             'total_score':'经理总分',
@@ -91,7 +99,7 @@ class ManagerDailyCollectionProcessor:
             'company_id':'基金公司',
         }
         self.result = df.rename(columns=replace_dic)[list(col_dic.keys())]
-        self.result = self.result.sort_values(['mng_id','fund_type','profit']).drop_duplicates(subset=['mng_id','fund_type'],keep='last')
+        self.result = self.result.drop_duplicates(subset=['mng_id','fund_type'])
 
     def insert(self):
         self.append_data(FundManagerDailyCollection.__tablename__, self.result)
