@@ -67,7 +67,16 @@ class ScoreFunc:
     beta_bond: float = 0
     alpha_hs300: float = 0
     beta_hs300: float = 0
-    active: float = -10 #默认条件不选择主动型，对主动性加分数惩罚
+    active: float = -10
+    FundMngScoreV1: float = 0
+    RetAbilityFundScore: float = 0
+    RiskAbilityFundScore: float = 0
+    StableAbility: float = 0
+    SelectTimeAbility: float = 0
+    SelectStockAbility: float = 0
+    WinRateMonthlyTop50: float = 0
+    WinRateMonthlyTop75: float = 0
+     #默认条件不选择主动型，对主动性加分数惩罚
     # last_year_alpha: float = 0
     # last_year_beta: float = 0
     # last_two_year_alpha: float = 0
@@ -113,7 +122,15 @@ class ScoreFunc:
                 + data.mng_fund_size.mul(other=self.mng_fund_size, fill_value=0) \
                 + data.mng_now_comp_year.mul(other=self.mng_now_comp_year, fill_value=0) \
                 + data.mng_year_ret_std.mul(other=self.mng_year_ret_std, fill_value=0) \
-                + data.active * self.active
+                + data.active * self.active \
+                + data.FundMngScoreV1.mul(other=self.FundMngScoreV1, fill_value=0) \
+                + data.RetAbilityFundScore.mul(other=self.RetAbilityFundScore, fill_value=0) \
+                + data.RiskAbilityFundScore.mul(other=self.RiskAbilityFundScore, fill_value=0) \
+                + data.StableAbility.mul(other=self.StableAbility, fill_value=0) \
+                + data.SelectTimeAbility.mul(other=self.SelectTimeAbility, fill_value=0) \
+                + data.SelectStockAbility.mul(other=self.SelectStockAbility, fill_value=0) \
+                + data.WinRateMonthlyTop50.mul(other=self.WinRateMonthlyTop50, fill_value=0) \
+                + data.WinRateMonthlyTop75.mul(other=self.WinRateMonthlyTop75, fill_value=0) 
                 # + self.down_risk * data.down_risk \
                 # + self.info_ratio * data.info_ratio \
                 # + self.ret_over_period * data.ret_over_period \
