@@ -679,6 +679,63 @@ class BondInFund(Base):
     bond_weight = Column(DOUBLE(asdecimal=False)) # 债券在基金权重
     fund_name = Column(CHAR(64)) # 基金名称
     
+class OverseaFundInfo(Base):
+    '''海外基金信息表'''
+
+    __tablename__ = 'oversea_fund_info'
+
+    codes = Column(CHAR(25), primary_key=True)  # 基金id
+    desc_name = Column(TEXT)  # 基金名称
+    company_name = Column(TEXT)  # 基金管理公司
+    fund_type = Column(CHAR(30))  # 基金类型
+    industry = Column(CHAR(20))  # 行业
+    area = Column(CHAR(20))  # 地区
+    latest_nav = Column(DOUBLE(asdecimal=False))  # 最新净值
+    fund_series = Column(Integer)  # 基金系列
+    is_new_fund = Column(BOOLEAN)  # 是否为新基金
+    redeem_dates = Column(Integer)  # 赎回资金到账天数
+    excg_out_t_delay = Column(Integer)  # 换出基金指示滞延时间
+    excg_in_t_delay = Column(Integer)  # 换入基金指示滞延时间
+    min_init_trade_amt = Column(Integer)  # 最低初始投资额
+    min_ag_trade_amt = Column(Integer)  # 最低后续投资额
+    min_redeem_type = Column(CHAR(10))  # 最小赎回类型
+    min_redeem_vol = Column(Integer)  # 最小赎回数量
+    min_pos_type = Column(CHAR(10))  # 最小持有类型
+    min_pos_vol = Column(Integer)  # 最小持有数量
+    purchase_period = Column(CHAR(128))  # 申购周期
+    risk_level = Column(CHAR(5))  # 风险级别
+    is_purchase = Column(BOOLEAN)  # 可供认购
+    is_CSRC_approve = Column(BOOLEAN)  # 证监会是否认可
+    yearly_fee = Column(DOUBLE(asdecimal=False))  # 年费
+    purchase_process_freq = Column(CHAR(10))  # 申购处理频率
+    money_type = Column(CHAR(10))  # 币种
+    is_sup_exchg_fund = Column(BOOLEAN)  # 支持转换基金
+    is_sup_same_series_fund = Column(BOOLEAN)  # 支持转换为同系列其他基金
+    is_sup_same_series_exchg = Column(BOOLEAN)  # 支持同系列其他基金转换为本基金
+    redeem_fee = Column(DOUBLE(asdecimal=False))  # 赎回费(%)
+    redeem_method = Column(CHAR(10))  # 赎回方式
+    is_derivatives = Column(BOOLEAN)  # 是否衍生产品
+    divident_distbt_mtd = Column(CHAR(10))  # 股息分派方式
+    divident_freq = Column(CHAR(15))  # 派息频率
+    asset_type = Column(CHAR(64))  # 资产类别
+    asset_code = Column(CHAR(32))  # 资产编号
+    issue_date = Column(DATE)  # 发行日期
+    issue_price = Column(DOUBLE(asdecimal=False))  # 发行价
+    fund_size_biln = Column(DOUBLE(asdecimal=False))  # 基金规模（单位：百万）
+    fund_size_calc_date = Column(DATE)  # 基金规模统计日期
+    fund_size_money_type = Column(CHAR(10))  # 基金规模币种
+    fee_rate = Column(DOUBLE(asdecimal=False))  # 费率
+    fee_calc_date = Column(DATE)  # 费率统计日期
+    is_compx_product = Column(BOOLEAN)  # 复杂产品
+
+class OverseaFundNav(Base):
+    '''海外基金信息表'''
+
+    __tablename__ = 'oversea_fund_nav'
+
+    codes = Column(CHAR(25), primary_key=True)  # 基金id
+    datetime = Column(DATE, primary_key=True) # 日期
+    nav = Column(DOUBLE(asdecimal=False)) # 净值
 class ETFInfo(Base):
 
     __tablename__ = 'etf_info'
@@ -690,4 +747,22 @@ class ETFInfo(Base):
     index_id = Column(CHAR(20)) # 指数id
     company_id = Column(CHAR(64)) # 基金公司
     etf_type = Column(CHAR(10)) # 场内场外类型
-    index_name = Column(CHAR(64)) # 指数名称
\ No newline at end of file
+    index_name = Column(CHAR(64)) # 指数名称
+
+class StockTag(Base):
+
+    __tablename__ = 'stock_tag'
+
+    tag_id = Column(CHAR(32), primary_key=True)  #标签id
+    stock_id = Column(CHAR(10), primary_key=True) # 股票id
+    tag_group_id = Column(CHAR(32), primary_key=True) # 标签组名 source_type_ymd
+    tag_name = Column(CHAR(64)) # 标签名
+
+class FundTag(Base):
+
+    __tablename__ = 'fund_tag'
+
+    tag_id = Column(CHAR(32), primary_key=True)  #标签id
+    fund_id = Column(CHAR(10), primary_key=True) # 基金id
+    tag_group_id = Column(CHAR(32), primary_key=True) # 标签组名 source_type_ymd
+    tag_name = Column(CHAR(64)) # 标签名
\ No newline at end of file
