@@ -699,7 +699,6 @@ class FundManagerDailyCollection(Base):
     mng_id = Column(CHAR(10), primary_key=True) # 基金经理id
     fund_type = Column(CHAR(20), primary_key=True) # 基金类型
     name = Column(CHAR(25)) # 姓名
-    profit = Column(DOUBLE(asdecimal=False)) # 任期收益
     mdd_history_daily = Column(DOUBLE(asdecimal=False)) # 历史最大回撤
     annual_ret_history_m = Column(DOUBLE(asdecimal=False)) # 历史年化收益
     total_score = Column(DOUBLE(asdecimal=False)) # 经理总分
@@ -726,7 +725,6 @@ class FundManagerDailyCollection(Base):
             'mng_id':'基金经理id',
             'name':'姓名',
             'fund_type':'基金类型',
-            'profit':'任期收益',
             'mdd_history_daily':'历史最大回撤',
             'annual_ret_history_m':'历史年化收益',
             'total_score':'经理总分',
