@@ -12,7 +12,7 @@ from .asset_helper import SAAHelper, TAAHelper, FAHelper
 from .trader import AssetTrader, FundTrader, BasicFundTrader
 from .report import ReportHelper
 from ...data.constant import _DEFAULT_CASH_VALUE
-from ...data.struct import FundTrade, FundWeight, FundWeightItem
+from ...data.struct import FundTrade, FundWeight, FundWeightItem, FundPosItem
 from ...data.manager.manager_fund import FundDataManager
 from ...data.manager.score import ScoreFunc, FundScoreManager
 from ...data.struct import AssetWeight, AssetPrice, AssetPosition, AssetValue, ScoreSelect
@@ -296,6 +296,22 @@ class BasicFundBacktestEngine(object):
                 fund_weight_list[i][0] = datetime.date.strftime(dt, '%Y-%m-%d')
                 i += 1
 
+    def repair_dict_trade_date(self, trades):
+        _dts = self._dm.get_trading_days().datetime
+        i = 0
+        for dt in _dts:
+            if i >= len(trades):
+                break
+            cur_date = datetime.datetime.strptime(trades[i].get('trade_date'), '%Y-%m-%d').date()
+            if dt < cur_date:
+                continue
+            if dt == cur_date:
+                i += 1
+                continue
+            if dt > cur_date:
+                trades[i]['trade_date'] = datetime.date.strftime(dt, '%Y-%m-%d')
+                i += 1
+
     def init(self):
         if not self._dm.inited:
             self._dm.init()
@@ -550,6 +566,190 @@ class AIPFundBackTestEngine(BasicFundBacktestEngine):
                                    current_deposit=current_deposit)
 
 
+class CashbookFundBackTestEngine(BasicFundBacktestEngine):
+
+    DEFAULT_CASH_VALUE = _DEFAULT_CASH_VALUE
+
+    def __init__(self, data_manager: FundDataManager, trader, init_position: list, trades_list: list):
+        self._dm = data_manager
+
+        # 修正 fund_weight_list
+        if init_position:
+            self.repair_trade_date(init_position)
+            fund_ids = []
+            for dt, fund_weight in init_position:
+                for i in fund_weight:
+                    fund_ids.append(i.get('fund_id'))
+            self._dm.confirm_fund_nav_exists(fund_ids)
+
+        if trades_list:
+            self.repair_dict_trade_date(trades_list)
+
+        self._report_helper = ReportHelper()
+        self._pending_trades = []
+        self._trader = trader
+        self._new_fund_position = {}
+        self._new_fund_cash = {}
+        self.cur_fund_position = None
+        self.cur_asset_position = AssetPosition(cash=1)
+        self.deposits = 0
+        self.withdraws = 0
+
+        self.current_deposit = 0
+        self.current_withdraw = 0
+        self._new_append_trades = {}
+
+        for dt, fund_weight in init_position:
+            dt = dt if isinstance(dt, datetime.date) else datetime.datetime.strptime(dt, '%Y-%m-%d').date()
+            self._new_fund_position[dt] = fund_weight
+            self._new_fund_cash[dt] = 0
+
+        for i in trades_list:
+            dt = i.get('trade_date')
+            dt = dt if isinstance(dt, datetime.date) else datetime.datetime.strptime(dt, '%Y-%m-%d').date()
+            if self._new_append_trades.get(dt):
+                self._new_append_trades[dt].append(i)
+            else:
+                self._new_append_trades[dt] = [i]
+
+        wind_index_map = {
+            '货币市场型基金': 'mmf',
+            '股票型基金': 'hs300',
+            '混合型基金': 'csi500',     # TODO: 临时代替，需设置正确映射关系！！！ 抄袭上面
+            '国际(QDII)基金': 'sp500rmb',
+            '另类投资基金': 'gold',
+            '债券型基金': 'national_debt',
+            '其他基金': 'hsi'           # TODO: 临时代替，需设置正确映射关系！！！
+        }
+        self._fund_wind_class = {
+            cur.fund_id: (wind_index_map[cur.wind_class_1] if cur.wind_class_1 in wind_index_map else 'hsi') for cur in self._dm.dts.fund_info.itertuples()
+        }
+
+    def run(self, start_date: datetime.date = None, end_date: datetime.date = None, cash: float = None, print_time=False):
+        # setup helpers
+        self.setup()
+
+        # init days
+        start_date = start_date or self._dm.start_date
+        end_date = end_date or self._dm.end_date
+        start_date = start_date if isinstance(start_date, datetime.date) else datetime.datetime.strptime(start_date,'%Y%m%d').date()
+        end_date = end_date if isinstance(end_date, datetime.date) else datetime.datetime.strptime(end_date,'%Y%m%d').date()
+
+        # loop trading days
+        _dts = self._dm.get_trading_days()
+        dts = _dts[(_dts.datetime >= start_date) & (_dts.datetime <= end_date)].datetime # df with datetime.date
+        for t in dts:
+            self._run_on(t, print_time=print_time)
+        # init report data
+        self._report_helper.plot_init(self._dm)
+
+    def _run_on(self, dt, print_time=False, cash=None):
+        _tm_start = time.time()
+        # prep data
+        self.prep_data(dt)
+        _tm_prep_data = time.time()
+        # calc trade
+        trade_list = self.calc_trade(dt, self.cur_asset_position, self.cur_fund_position)
+        _tm_calc_trade = time.time()
+        # book trade
+        self.book_trades(trade_list)
+
+        # finalize trade
+        if self.cur_fund_position:
+            traded_list = self.finalize_trade(dt, self._pending_trades, self.cur_asset_position, self.cur_fund_position)
+            self.cur_fund_position.cash = 0
+        else:
+            traded_list = []
+        _tm_finalize_trade = time.time()
+
+        # update
+        self.update_cash(traded_list)
+        self.update_reporter(dt, traded_list, self.cur_asset_position, self.cur_fund_position)
+        self.current_withdraw = 0
+        self.current_deposit = 0
+        if self._pending_trades:
+            print(self._pending_trades)
+        _tm_finish = time.time()
+
+        if print_time:
+            print(f'{dt} (tot){_tm_finish - _tm_start} (finalize){_tm_finalize_trade - _tm_start} (calc){_tm_calc_trade - _tm_finalize_trade} (misc){_tm_finish - _tm_calc_trade}')
+
+    def calc_trade(self, dt, cur_asset_position: AssetPosition, cur_fund_position: FundPosition=None, is_real_trade=False):
+
+        if dt in self._new_fund_position:
+            position_list = self._new_fund_position[dt]
+            cur_cash = sum([i.get('amount') for i in position_list])
+            self.cur_fund_position = FundPosition(cash=cur_cash)
+
+            trade_list = []
+            for i in position_list:
+                fund_id = i['fund_id']
+                _trade = FundTrade(
+                    fund_id=fund_id,
+                    index_id=self._fund_wind_class[fund_id],
+                    mark_price=0,
+                    amount=i['amount'],
+                    is_buy=True,
+                    submit_date=dt
+                )
+                trade_list.append(_trade)
+            return trade_list
+
+        if dt in self._new_append_trades:
+            if not self.cur_fund_position:
+                self.cur_fund_position = FundPosition(cash=0)
+            append_trades = self._new_append_trades[dt]
+
+            trade_list = []
+            for i in append_trades:
+                trade_type = i.get('trade_type')
+                fund_id = i['fund_id']
+
+                if trade_type == 'buy':
+                    _trade = FundTrade(
+                        fund_id=fund_id,
+                        index_id=self._fund_wind_class[fund_id],
+                        mark_price=0,
+                        amount=i['amount'],
+                        is_buy=True,
+                        submit_date=dt
+                    )
+                    self.cur_fund_position.cash = self.cur_fund_position.cash + i['amount']
+                    trade_list.append(_trade)
+                elif trade_type == 'sell':
+                    if i['sell_rate']:
+                        volume = self.cur_fund_position.funds.get(fund_id).volume * i['sell_rate']
+                    else:
+                        volume = i['volume']
+                    _trade = FundTrade(
+                        fund_id=fund_id,
+                        index_id=self._fund_wind_class[fund_id],
+                        mark_price=0,
+                        volume=volume,
+                        is_buy=False,
+                        submit_date=dt
+                    )
+                    trade_list.append(_trade)
+            return trade_list
+        return []
+
+    def update_cash(self, traded_list):
+        for trd in traded_list:
+            if trd.is_buy is True:
+                self.current_deposit += trd.amount
+                self.deposits += trd.amount
+            else:
+                self.current_withdraw += trd.amount
+                self.withdraws += trd.amount
+
+    def update_reporter(self, dt, trade_list, cur_asset_position: AssetPosition,
+                        cur_fund_position: FundPosition = None, current_deposit=None, current_withdraw=None):
+        self._report_helper.update(dt, cur_asset_position, self._prep_asset_price, self._pending_trades,
+                                   cur_fund_position, self._prep_fund_nav, trade_list, None, None, None,
+                                   current_deposit=self.current_deposit, current_withdraw=self.current_withdraw,
+                                   deposit=self.deposits, withdraw=self.withdraws,
+                                   )
+
 def saa_backtest(m: FundDataManager, saa: AssetWeight):
     asset_param = AssetTradeParam() # type in here
     t = AssetTrader(asset_param)
