@@ -276,7 +276,7 @@ class FundTrader(AssetTrader):
             if trade_status:
                 traded_list.append(trd)
                 if trd.fund_id in disproved_set:
-                    print(f' trade bannded fund dt {dt} fund_id {trd.fund_id} index_id {trd,index_id}')
+                    print(f' trade bannded fund dt {dt} fund_id {trd.fund_id} index_id {trd.index_id}')
             else:
                 pass
                 #print(f'trade failed alert : {trd}')
@@ -413,6 +413,18 @@ class FundTrader(AssetTrader):
                                                   fund_rebalance_min_score,
                                                   _fund_rebalance_min_name,
                                                   self.fund_param.JudgeFundRebalance)
+
+        trigger_detail = TradeTrigger.trigger_detail(trigger,
+                                                  index_rebalance_max_diff,
+                                                  _index_rebalance_max_diff_name,
+                                                  self.fund_param.JudgeIndexDiff,
+                                                  fund_selection_min_score,
+                                                  _fund_selection_min_name,
+                                                  self.fund_param.JudgeFundSelection,
+                                                  fund_rank_list,
+                                                  fund_rebalance_min_score,
+                                                  _fund_rebalance_min_name,
+                                                  self.fund_param.JudgeFundRebalance)
         
         
         if trigger > 0:
@@ -425,7 +437,7 @@ class FundTrader(AssetTrader):
             else:
                 trigger = 0
                 #print(f'judge dismiss {dt} (trigger){TradeTrigger.parse(trigger)} (Fs){fund_selection_min_score}[{_fund_selection_min_name}]#{self.fund_param.JudgeFundSelection} (Fr){fund_rebalance_min_score}/[{_fund_rebalance_min_name}]#{self.fund_param.JudgeFundRebalance} (Ir){index_rebalance_max_diff}/[{_index_rebalance_max_diff_name}]#{self.fund_param.JudgeIndexDiff}')
-        return trigger, trigger_reason
+        return trigger, trigger_reason, trigger_detail
 
     def calc_trade(self, dt,
             tar_fund_weight: FundWeight,
@@ -452,19 +464,19 @@ class FundTrader(AssetTrader):
         if is_real_trade:
             for fund_id, pos_info in cur_fund_position.funds.items():
                 pos_info.volume = pos_info.unit_volume
-            trigger, trigger_reason = self.judge_trade(dt, index_fund_cache, 
+            trigger, trigger_reason, trigger_detail = self.judge_trade(dt, index_fund_cache, 
                                         tar_fund_weight, tar_asset_weight,
                                         cur_fund_position, cur_asset_position, cur_fund_unit_nav, 
                                         cur_fund_score, cur_asset_price, score_select, fund_end_date_dict)
         else:
-            trigger, trigger_reason = self.judge_trade(dt, index_fund_cache, 
+            trigger, trigger_reason, trigger_detail = self.judge_trade(dt, index_fund_cache, 
                                         tar_fund_weight, tar_asset_weight,
                                         cur_fund_position, cur_asset_position, cur_fund_nav, 
                                         cur_fund_score, cur_asset_price, score_select, fund_end_date_dict)
         
         # 如果是真实交易 且cash 不为零，按照当日cash，返回买单
         if (is_real_trade is False and trigger == 0) or (is_real_trade is True and cur_fund_position.cash == 0 and trigger == 0):
-            return cur_fund_position, [], {}
+            return cur_fund_position, [], {}, trigger_detail
 
         fund_trades = self.get_trades(dt, index_fund_cache, 
                                     tar_fund_weight, tar_asset_weight,
@@ -476,7 +488,7 @@ class FundTrader(AssetTrader):
         for _trade in fund_trades:
             _trade.trigger = trigger
             new_fund_position.update(_trade)
-        return new_fund_position, fund_trades, trigger_reason
+        return new_fund_position, fund_trades, trigger_reason, trigger_detail
 
     def get_trades(self, dt,
             index_fund_cache, 
