@@ -3,9 +3,10 @@ import numpy as np
 import math
 import json
 import re
+import datetime
 from typing import Optional, List, Union, Dict
 from .base import Factor
-from .utils import _START_DATE, _END_DATE
+from .utils import _START_DATE
 from ...data.manager import DataManager
 from ...data.manager.fund_info_filter import fund_info_update, get_conv_funds, filter_fund_info, active_fund_info as get_active_fund_info
 from ...data.struct import AssetTimeSpan
@@ -61,7 +62,7 @@ class TradingDay(Factor):
     def calc(self):
         self._factor = DataManager.basic_data(func_name='get_trading_day_list').set_index('datetime').drop(columns=['_update_time'], errors='ignore')
         self._factor = self._factor[(self._factor.index >= pd.to_datetime(_START_DATE).date())
-                                 & (self._factor.index <= pd.to_datetime(_END_DATE).date())]
+                                 & (self._factor.index < datetime.datetime.now().date())]
 
 class IndexInfo(Factor):
 
@@ -241,17 +242,6 @@ class FundCompanyHold(Factor):
         self._factor = self._factor.pivot(index='datetime',columns='fund_id',values='institution_holds')
         self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
 
-class FundPersonHold(Factor):
-
-    def __init__(self):
-        super().__init__(f_name='FundPersonHold', f_type=FundFactorType.BASIC, f_level='basic')
-        self._deps.add(TradingDay())
-
-    def calc(self):
-        self._factor = DataManager.basic_data(func_name='get_fund_persional_hold', start_date=_START_DATE).drop(columns=['_update_time'], errors='ignore')
-        self._factor = self._factor.pivot(index='datetime',columns='fund_id',values='personal_holds')
-        self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
-
 class FundRetDailyModify(Factor): # based on fund_info fund_ret_daily
 
     def __init__(self):
@@ -275,6 +265,37 @@ class FundRetDailyModify(Factor): # based on fund_info fund_ret_daily
         self._factor = self.data_reindex_daily_trading_day(self._factor, TradingDay().get())
         self._factor = self._factor.loc[:,~self._factor.columns.duplicated()].copy()
 
+class FundInfoAsset(Factor):
+
+    def __init__(self):
+        super().__init__(f_name='FundInfoAsset', f_type=FundFactorType.BASIC, f_level='basic')
+        self._deps.add(FundInfo())
+        self._deps.add(ActiveFundInfo())
+        self._deps.add(FundRetDailyModify())
+
+    def calc(self):
+        fund_info = FundInfo().get()
+        active_fund_info = ActiveFundInfo().get()
+        fund_ret = FundRetDailyModify().get()
+
+        index_list = list(AssetTimeSpan.__dataclass_fields__.keys())
+        fund_to_index_dict = fund_info[fund_info.index_id.isin(index_list)][['fund_id', 'index_id']].set_index('fund_id').to_dict()['index_id']
+        index_fund = { index_id : [fund_idx for fund_idx, index_idx in fund_to_index_dict.items() if index_idx == index_id] for index_id in index_list}
+        if 'active' in index_fund.keys():
+            del index_fund['active']
+        if 'conv_bond' in index_fund.keys():
+            del index_fund['conv_bond']
+        for index_id, fund_list in index_fund.items():
+            active_list = active_fund_info[active_fund_info.index_id == index_id].fund_id
+            fund_list = list(set(active_list).union(set(fund_list)).intersection(fund_ret.columns))
+            index_fund[index_id] = fund_list
+        fund_to_index = {}
+        for index_id, fund_list in index_fund.items():
+            for fund_id in fund_list:
+                fund_to_index[fund_id] = index_id
+        fund_info.loc[:,'bk_index_id'] = fund_info.fund_id.map(lambda x : fund_to_index.get(x))
+        self._factor = fund_info
+
 class FundRetWeeklyModify(Factor): # based on FundRetDailyModify
 
     def __init__(self):
