@@ -16,32 +16,39 @@ from ..fund.engine.asset_helper import TAAHelper, TAAStatusMode
 from ..data.wrapper.mysql import *
 from ..data.view.basic_models import *
 from ..data.view.derived_models import *
+from .calculator_item import CalculatorBase
 
 @dataclasses.dataclass
 class SeriesStatUnit:
 
-    start_date: datetime.date   # 序列的开始时间
-    end_date: datetime.date     # 序列的结束时间
-    trade_year: float           # 交易年限
-    last_unit_nav: float        # 末期单位净值
-    annualized_ret: float       # 年化收益
-    annualized_vol: float       # 年化波动率
-    sharpe: float               # 夏普率
-    recent_y1_ret: float        # 近一年收益
-    recent_y5_ret: float        # 近五年收益 
-    mdd: float                  # 最大回撤
-    mdd_date1: datetime.date    # 最大回撤开始时间
-    mdd_date2: datetime.date    # 最大回撤结束时间
-    mdd_lens: int               # 最大回撤区间持续时间
-    ret_over_mdd: float         # Calmar 年化收益除以最大回撤
-    last_mv_diff: float         # 末期市值增量              
-    last_increase_rate: float   # 末期涨幅
-    worst_3m_ret: float         # 最差三月收益
-    worst_6m_ret: float         # 最差六月收益
-    recent_drawdown: float      # 最近回撤
-    downside_std :float         # 下行风险
-    var : float                 # 风险价值VaR
-    cvar: float                 # 条件风险价值 CVaR
+    start_date: datetime.date           # 序列的开始时间
+    end_date: datetime.date             # 序列的结束时间
+    trade_year: float                   # 交易年限
+    last_unit_nav: float                # 末期单位净值
+    annualized_ret: float               # 年化收益
+    annualized_vol: float               # 年化波动率
+    sharpe: float                       # 夏普率
+    recent_1m_ret: float                # 最近1月收益
+    recent_3m_ret: float                # 最近3月收益
+    recent_6m_ret: float                # 最近6月收益
+    recent_y1_ret: float                # 近一年收益
+    recent_y3_ret: float                # 近三年收益
+    recent_y5_ret: float                # 近五年收益
+    mdd: float                          # 最大回撤
+    mdd_date1: datetime.date            # 最大回撤开始时间
+    mdd_date2: datetime.date            # 最大回撤结束时间
+    mdd_lens: int                       # 最大回撤区间持续时间
+    ret_over_mdd: float                 # Calmar 年化收益除以最大回撤
+    last_mv_diff: float                 # 末期市值增量              
+    last_increase_rate: float           # 末期涨幅
+    worst_3m_ret: float                 # 最差三月收益
+    worst_6m_ret: float                 # 最差六月收益
+    recent_drawdown: float              # 最近回撤
+    recent_mdd_date1: datetime.date     # 最近回撤开始时间
+    downside_std :float                 # 下行风险
+    var : float                         # 风险价值VaR
+    cvar: float                         # 条件风险价值 CVaR
+
 
 @dataclasses.dataclass
 class BenchmarkSeiesStatUnit(SeriesStatUnit):
@@ -86,101 +93,81 @@ class Calculator:
     @staticmethod
     def get_stat_result(dates: pandas.core.series.Series,
                         values: pandas.core.series.Series,
-                        frequency:str='daily'):
-        assert len(dates) == len(values), 'date and value has different numbers'
-        
-        if len(dates) > 1:
-            sr = pandas.Series(values, index=dates).sort_index()
-            sr_ret = sr.pct_change(1)
-            risk_fee_rate = Calculator.get_risk_free_rate()
-            start_date = sr.index[0] 
-            end_date = sr.index[-1]
-            yearly_multiplier = Calculator.get_yearly_multiplier(frequency)
-            trade_year = sr.shape[0] * yearly_multiplier / Calculator.TRADING_DAYS_PER_YEAR
-            last_unit_nav = sr[-1] / sr[0]
-            annualized_ret = np.exp(np.log(last_unit_nav) / trade_year) - 1
-            annualized_vol = (sr / sr.shift(1)).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR / yearly_multiplier)
-            sharpe = (annualized_ret - risk_fee_rate) / annualized_vol
-            recent_drawdown = 1 - (sr[-1] / sr.max())
-            if sr.shape[0] * yearly_multiplier > Calculator.TRADING_DAYS_PER_YEAR * 5:
-                recent_y5_ret  = sr[-1] / sr[- int(Calculator.TRADING_DAYS_PER_YEAR * 5 / yearly_multiplier)] - 1
-            else:
-                recent_y5_ret = sr[-1] / sr[0] - 1
-
-            if sr.shape[0] * yearly_multiplier > Calculator.TRADING_DAYS_PER_YEAR:
-                recent_y1_ret  = sr[-1] / sr[- int(Calculator.TRADING_DAYS_PER_YEAR * 1 / yearly_multiplier)] - 1
-            else:
-                recent_y1_ret = sr[-1] / sr[0] - 1
-            worst_3m_ret = sr.pct_change(60).min()
-            worst_6m_ret = sr.pct_change(120).min()
-            mdd_part =  sr[:] / sr[:].rolling(window=sr.shape[0], min_periods=1).max()
-            mdd = 1 - mdd_part.min()
-            if np.isnan(mdd):
-                mdd_date2 = None
-                mdd_date1 = None
-                mdd_lens = None
-            else:
-                mdd_date2 = mdd_part.idxmin()
-                mdd_date1 = sr[:mdd_date2].idxmax()
-                _mdd_date1 = Calculator.get_datatime_date(mdd_date1)
-                _mdd_date2 = Calculator.get_datatime_date(mdd_date2)
-                mdd_lens = (_mdd_date2-_mdd_date1).days
-            
-            ret_over_mdd = annualized_ret / mdd if mdd != 0 else None
-            last_mv_diff = sr[-1] - sr[-2]
-            last_increase_rate = (sr[-1] - sr[-2])/ sr[-2]
-            risk_free_period = risk_fee_rate / Calculator.TRADING_DAYS_PER_YEAR * yearly_multiplier
-            downside_std = sr_ret[sr_ret < risk_free_period].std(ddof=1)
-            var = np.quantile(sr_ret, 0.05)
-            cvar = sr_ret[sr_ret <= var].mean()
-        # 如果只输入一天，返回空
-        else:
-            start_date = dates[0] if len(dates) > 0 else None
-            end_date = dates[0] if len(dates) > 0 else None
-            recent_y1_ret = 0
-            trade_year = 0
-            last_unit_nav = 1
-            annualized_ret = 0
-            annualized_vol = 0
-            sharpe = 0 
-            recent_y5_ret = 0
-            mdd = 0
-            mdd_date1 = dates[0] if len(dates) > 0 else None
-            mdd_date2 = dates[0] if len(dates) > 0 else None
-            mdd_lens = 0
-            ret_over_mdd = 0
-            last_mv_diff = 0
-            last_increase_rate = 0
-            recent_drawdown = 0
-            worst_3m_ret = 0
-            worst_6m_ret = 0
-            downside_std = 0
-            var = 0
-            cvar = 0
-
+                        frequency:str='1D'): #['1D','1W','2W','1M']
+        res = CalculatorBase.get_stat_result(dates=dates,values=values,frequency=frequency)
         return SeriesStatUnit(
-            start_date=start_date,
-            end_date=end_date,
-            trade_year=trade_year,
-            last_unit_nav=last_unit_nav,
-            annualized_ret=annualized_ret,
-            annualized_vol=annualized_vol,
-            sharpe=sharpe,
-            recent_y1_ret=recent_y1_ret,
-            recent_y5_ret=recent_y5_ret,
-            worst_3m_ret=worst_3m_ret,
-            worst_6m_ret=worst_6m_ret,     
-            mdd=mdd,
-            mdd_date1=mdd_date1,
-            mdd_date2=mdd_date2,
-            mdd_lens=mdd_lens,
-            ret_over_mdd=ret_over_mdd,
-            last_mv_diff=last_mv_diff,
-            last_increase_rate=last_increase_rate,
-            recent_drawdown=recent_drawdown,
-            downside_std=downside_std,
-            var=var,
-            cvar=cvar,
+            start_date=res['start_date'],
+            end_date=res['end_date'],
+            trade_year=res['trade_year'],
+            last_unit_nav=res['last_unit_nav'],
+            annualized_ret=res['annual_ret'],
+            annualized_vol=res['annual_vol'],
+            sharpe=res['sharpe'],
+            recent_1m_ret=res['recent_1m_ret'],
+            recent_3m_ret=res['recent_3m_ret'],
+            recent_6m_ret=res['recent_6m_ret'],
+            recent_y1_ret=res['recent_1y_ret'],
+            recent_y3_ret=res['recent_3y_ret'],
+            recent_y5_ret=res['recent_5y_ret'],
+            worst_3m_ret=res['worst_3m_ret'],
+            worst_6m_ret=res['worst_6m_ret'],   
+            mdd=res['mdd'],
+            mdd_date1=res['mdd_date1'],
+            mdd_date2=res['mdd_date2'],
+            mdd_lens=res['mdd_lens'],
+            ret_over_mdd=res['calmar'],
+            last_mv_diff=res['last_mv_diff'],
+            last_increase_rate=res['last_increase_rate'],
+            recent_drawdown=res['recent_drawdown'],
+            recent_mdd_date1 = res['recent_mdd_date1'],
+            downside_std=res['downside_risk'],
+            var=res['var'],
+            cvar=res['cvar'],
+        )
+
+    @staticmethod
+    def get_benchmark_stat_result(dates: pandas.core.series.Series,
+                                  values: pandas.core.series.Series,
+                                  benchmark_values: pandas.core.series.Series,
+                                  frequency:str='1D'):#['1D','1W','2W','1M']
+        res = CalculatorBase.get_stat_result(dates=dates,values=values,benchmark_values=benchmark_values,frequency=frequency)
+        return BenchmarkSeiesStatUnit(
+            start_date=res['start_date'],
+            end_date=res['end_date'],
+            trade_year=res['trade_year'],
+            last_unit_nav=res['last_unit_nav'],
+            annualized_ret=res['annual_ret'],
+            annualized_vol=res['annual_vol'],
+            sharpe=res['sharpe'],
+            recent_y5_ret=res['recent_5y_ret'],
+            mdd=res['mdd'],
+            mdd_date1=res['mdd_date1'],
+            mdd_date2=res['mdd_date2'],
+            mdd_lens=res['mdd_lens'],
+            ret_over_mdd=res['calmar'],
+            alpha=res['alpha'],
+            beta=res['beta'],
+            track_err=res['track_err'],
+            ir=res['info'],
+            last_mv_diff=res['last_mv_diff'],
+            last_increase_rate=res['last_increase_rate'],
+            recent_1m_ret=res['recent_1m_ret'],
+            recent_3m_ret=res['recent_3m_ret'],
+            recent_6m_ret=res['recent_6m_ret'],
+            recent_y1_ret=res['recent_1y_ret'],
+            recent_y3_ret=res['recent_3y_ret'],
+            worst_3m_ret=res['worst_3m_ret'],
+            worst_6m_ret=res['worst_6m_ret'],
+            recent_drawdown=res['recent_drawdown'],
+            recent_mdd_date1 = res['recent_mdd_date1'],
+            downside_std=res['downside_risk'],
+            var=res['var'],
+            cvar=res['cvar'],
+            win_rate=res['win_rate'],
+            treynor=res['treynor'],
+            alpha_cl=res['alpha_cl'],
+            beta_cl=res['beta_cl'],
+            continue_value=res['continue_value_m'],
         )
 
     @staticmethod
@@ -310,115 +297,6 @@ class Calculator:
         continue_regress_v = res.params[0]
         return continue_regress_v
 
-    @staticmethod
-    def get_benchmark_stat_result(dates: pandas.core.series.Series,
-                                  values: pandas.core.series.Series,
-                                  benchmark_values: pandas.core.series.Series,
-                                  frequency:str='daily'):
-        
-        assert len(dates) == len(values), 'date and port_values has different numbers'
-        assert len(dates) == len(benchmark_values), 'date and bench_values has different numbers'
-        res = Calculator.get_stat_result(dates, values,frequency)
-        sr_values  = pandas.Series(values, index=dates).sort_index()  
-        sr_values = sr_values / sr_values[0]
-        sr_values.name = 'fund'
-        sr_benchmark_values = pandas.Series(benchmark_values, index=dates).sort_index()  
-        sr_benchmark_values = sr_benchmark_values / sr_benchmark_values[0]
-        sr_benchmark_values.name = 'benchmark'
-        yearly_multiplier = Calculator.get_yearly_multiplier(frequency)
-        sr_values_ret = sr_values.pct_change(1)
-        sr_benchmark_ret = sr_benchmark_values.pct_change(1)
-        x = sr_benchmark_ret.dropna().values
-        y = sr_values_ret.dropna().values
-        ex_ret = y - x
-        win_rate = len(ex_ret[ex_ret > 0]) / len(ex_ret)
-        x = sm.add_constant(x)
-        if x.shape[1] < 2:
-            return BenchmarkSeiesStatUnit(
-                start_date=res.start_date,
-                end_date=res.end_date,
-                trade_year=res.trade_year,
-                last_unit_nav=res.last_unit_nav,
-                annualized_ret=res.annualized_ret,
-                annualized_vol=res.annualized_vol,
-                sharpe=res.sharpe,
-                recent_y5_ret=res.recent_y5_ret,
-                mdd=res.mdd,
-                mdd_date1=res.mdd_date1,
-                mdd_date2=res.mdd_date2,
-                mdd_lens=res.mdd_lens,
-                ret_over_mdd=res.ret_over_mdd,
-                alpha=np.nan,
-                beta=np.nan,
-                track_err=np.nan,
-                ir=np.nan,
-                last_mv_diff=res.last_mv_diff,
-                last_increase_rate=res.last_increase_rate,
-                recent_y1_ret=res.recent_y1_ret,
-                worst_3m_ret=res.worst_3m_ret,
-                worst_6m_ret=res.worst_6m_ret,
-                recent_drawdown=res.recent_drawdown,
-                downside_std=res.downside_std,
-                var=res.var,
-                cvar=res.cvar,
-                win_rate=np.nan,
-                treynor=np.nan,
-                alpha_cl=np.nan,
-                beta_cl=np.nan,
-                continue_value=np.nan,
-        )
-        model = regression.linear_model.OLS(y,x).fit()
-        x = x[:,1]
-        alpha = model.params[0] * Calculator.TRADING_DAYS_PER_YEAR / yearly_multiplier
-        beta = model.params[1]
-        track_err = (sr_values_ret - sr_benchmark_ret).std(ddof=1) * np.sqrt(Calculator.TRADING_DAYS_PER_YEAR / yearly_multiplier)
-        ir = alpha / track_err
-        risk_fee_rate = Calculator.get_risk_free_rate()
-        risk_free_period = risk_fee_rate / Calculator.TRADING_DAYS_PER_YEAR * yearly_multiplier
-        treynor = (np.nanmean(y) - risk_free_period) / beta if beta != 0 else np.nan
-        df = pandas.concat([sr_values,sr_benchmark_values],axis=1)
-        df_monthly = df.set_axis(pandas.to_datetime(df.index), inplace=False).resample(rule='1M').last()
-        df_monthly.index = df_monthly.index.date
-        monthly_ret = df_monthly.pct_change(1).dropna()
-        cl_res = Calculator.calc_cl_alpha_beta(monthly_ret.to_numpy())
-        alpha_cl = cl_res['alpha']
-        beta_cl = cl_res['beta']
-        continue_value = Calculator.calc_continue_regress_v(monthly_ret.fund)
-
-        return BenchmarkSeiesStatUnit(
-            start_date=res.start_date,
-            end_date=res.end_date,
-            trade_year=res.trade_year,
-            last_unit_nav=res.last_unit_nav,
-            annualized_ret=res.annualized_ret,
-            annualized_vol=res.annualized_vol,
-            sharpe=res.sharpe,
-            recent_y5_ret=res.recent_y5_ret,
-            mdd=res.mdd,
-            mdd_date1=res.mdd_date1,
-            mdd_date2=res.mdd_date2,
-            mdd_lens=res.mdd_lens,
-            ret_over_mdd=res.ret_over_mdd,
-            alpha=alpha,
-            beta=beta,
-            track_err=track_err,
-            ir=ir,
-            last_mv_diff=res.last_mv_diff,
-            last_increase_rate=res.last_increase_rate,
-            recent_y1_ret=res.recent_y1_ret,
-            worst_3m_ret=res.worst_3m_ret,
-            worst_6m_ret=res.worst_6m_ret,
-            recent_drawdown=res.recent_drawdown,
-            downside_std=res.downside_std,
-            var=res.var,
-            cvar=res.cvar,
-            win_rate=win_rate,
-            treynor=treynor,
-            alpha_cl=alpha_cl,
-            beta_cl=beta_cl,
-            continue_value=continue_value,
-        )
-
     @staticmethod
     def get_benchmark(index_price: pandas.DataFrame,
                         weight_list: list,
@@ -451,7 +329,7 @@ class Calculator:
     def get_stat_result_from_df(df: pandas.DataFrame,
                                 date_column: str,
                                 value_column: str,
-                                frequency: str = 'daily'):
+                                frequency: str = '1D'):
         dates = df[date_column].values
         values = df[value_column].values
         return Calculator.get_stat_result(dates, values, frequency)
@@ -461,7 +339,7 @@ class Calculator:
                                           date_column: str,
                                           port_value_column: str,
                                           bench_value_column: str,
-                                          frequency: str = 'daily'
+                                          frequency: str = '1D'
                                           ):
         dates = df[date_column].values
         port_values = df[port_value_column].values
